diff --git a/MSVC/config.h b/MSVC/config.h
index 209ea5cde3a0fed5911d6e8d8095274bb75cb134..35634dfc3c0288c625c957ccaa82876c070f1f54 100644
--- a/MSVC/config.h
+++ b/MSVC/config.h
@@ -203,7 +203,7 @@ STACK_DIRECTION = 0 => direction of growth unknown */
 /* Version number of package */
 #define VERSION "2.3.0"
 
-// UWP compatability
+// UWP compatibility
 #define PROGSHAREDIR ""
 
 /* Define to limit the scope of <windows.h>. */
diff --git a/bin/dbus/cx.ring.Ring.CallManager.xml b/bin/dbus/cx.ring.Ring.CallManager.xml
index c2ae995013f29dc86beee4fa083fa3a9fdae70f3..26ee902fdd05a9a3042a9807a1835941612f7deb 100644
--- a/bin/dbus/cx.ring.Ring.CallManager.xml
+++ b/bin/dbus/cx.ring.Ring.CallManager.xml
@@ -178,7 +178,7 @@
             </tp:docstring>
             <arg type="s" name="transferID" direction="in">
               <tp:docstring>
-                The callID of the call to be transfered.
+                The callID of the call to be transferred.
               </tp:docstring>
             </arg>
             <arg type="s" name="targetID" direction="in">
@@ -271,7 +271,7 @@
             <tp:docstring>
                 Detach local participant from the conference.
                 Remote participants are placed in hold.
-                The signal <tp:member-ref>conferenceChanged</tp:member-ref> is emited.
+                The signal <tp:member-ref>conferenceChanged</tp:member-ref> is emitted.
             </tp:docstring>
             <arg type="b" name="detachSucceeded" direction="out"/>
         </method>
@@ -279,7 +279,7 @@
         <method name="detachParticipant" tp:name-for-bindings="detachParticipant">
             <tp:added version="0.9.7"/>
             <tp:docstring>
-              Detach the given call from the conference. If only one participant is left, the conference is deleted and the signal <tp:member-ref>conferenceRemoved</tp:member-ref> is emited.
+              Detach the given call from the conference. If only one participant is left, the conference is deleted and the signal <tp:member-ref>conferenceRemoved</tp:member-ref> is emitted.
             </tp:docstring>
             <arg type="s" name="callID" direction="in">
               <tp:docstring>
@@ -342,7 +342,7 @@
         <method name="getConferenceId" tp:name-for-bindings="getConferenceId">
             <tp:added version="1.1.0"/>
             <tp:docstring>
-                If thsi call participate to a conference, return the conference id.
+                If this call participate to a conference, return the conference id.
                 Return an empty string elsewhere.
             </tp:docstring>
             <arg type="s" name="callID" direction="in">
@@ -415,7 +415,7 @@
 
         <signal name="recordPlaybackFilepath" tp:name-for-bindings="recordPlaybackFilepath">
             <tp:docstring>
-              Once after starting recording for the first time, this signal is emited to
+              Once after starting recording for the first time, this signal is emitted to
               provide the recorded file path to client application.
             </tp:docstring>
             <arg type="s" name="callID" />
@@ -650,7 +650,7 @@
         <signal name="conferenceCreated" tp:name-for-bindings="conferenceCreated">
             <tp:added version="0.9.7"/>
             <tp:docstring>
-              Emited when a new conference is created. Ring-client is reponsible for storing the confID and call <tp:member-ref>getParticipantList</tp:member-ref> to update the display.
+              Emitted when a new conference is created. Ring-client is responsible for storing the confID and call <tp:member-ref>getParticipantList</tp:member-ref> to update the display.
             </tp:docstring>
             <arg type="s" name="confID">
               <tp:docstring>
@@ -662,7 +662,7 @@
         <signal name="conferenceRemoved" tp:name-for-bindings="conferenceRemoved">
             <tp:added version="0.9.7"/>
             <tp:docstring>
-              Emited when a new conference is remove. Ring-client should have kept a list of current participant in order to display modification.
+              Emitted when a new conference is remove. Ring-client should have kept a list of current participant in order to display modification.
             </tp:docstring>
             <arg type="s" name="confID">
               <tp:docstring>
@@ -727,7 +727,7 @@
         <signal name="transferSucceeded" tp:name-for-bindings="transferSucceeded">
             <tp:docstring>
               <p>Transfer has been successfully
-              processed. Client should remove transfered
+              processed. Client should remove transferred
               call from call list as it is no longer
               accessible in Ring-daemon (dring).</p>
             </tp:docstring>
diff --git a/bin/dbus/cx.ring.Ring.ConfigurationManager.xml b/bin/dbus/cx.ring.Ring.ConfigurationManager.xml
index 2e447563b9dfb4d359af7c3c65dc435b30724f45..6881f7fae81b5fc23e64183b8c46dae50d3ed26e 100644
--- a/bin/dbus/cx.ring.Ring.ConfigurationManager.xml
+++ b/bin/dbus/cx.ring.Ring.ConfigurationManager.xml
@@ -32,7 +32,7 @@
                         <li>CONFIG_ACCOUNT_ENABLE:    True or False (Default: True)</li>
                         <li>CONFIG_ACCOUNT_RESOLVE_ONCE</li>
                         <li>CONFIG_ACCOUNT_TYPE: SIP or RING</li>
-                        <li>HOSTNAME: The IP adress or hostname of the registrar</li>
+                        <li>HOSTNAME: The IP address or hostname of the registrar</li>
                         <li>USERNAME: The username (or extension) of the account</li>
                         <li>PASSWORD: The password associated to the account</li>
                         <li>REALM</li>
@@ -1183,7 +1183,7 @@
            </arg>
            <arg type="b" name="success" direction="out">
                <tp:docstring>
-                   <p>True if the certificate state was succesfully set.</p>
+                   <p>True if the certificate state was successfully set.</p>
                </tp:docstring>
            </arg>
        </method>
diff --git a/bin/restcpp/restclient.cpp b/bin/restcpp/restclient.cpp
index 02d8e2e57c15f90d82566e09a05f39afb3b01779..362645df47b18a7def0a0fcbd7840dd97a77b665 100644
--- a/bin/restcpp/restclient.cpp
+++ b/bin/restcpp/restclient.cpp
@@ -103,7 +103,7 @@ RestClient::initLib(int flags)
 
     // Configuration event handlers
 
-    // This is a short example of a callbakc using a lambda. In this case, this displays the incomming messages
+    // This is a short example of a callback using a lambda. In this case, this displays the incoming messages
     const std::map<std::string, SharedCallback> configEvHandlers = {
         exportable_callback<ConfigurationSignal::IncomingAccountMessage>([]
             (const std::string& accountID, const std::string& from, const std::map<std::string, std::string>& payloads){
@@ -146,7 +146,7 @@ RestClient::initResources()
     // This is the function that initiates the resources.
     // Each resources is defined by a route and a void function with a shared pointer to the session as argument
 
-    // In this case, here's an example of the default route. It will list all the managers availables
+    // In this case, here's an example of the default route. It will list all the managers available
     auto default_res = std::make_shared<restbed::Resource>();
     default_res->set_path("/");
     default_res->set_method_handler("GET", [](const std::shared_ptr<restbed::Session> session){
diff --git a/src/account_schema.h b/src/account_schema.h
index 07385582d4484094ad6c64220b98b81b0722aaa3..66e292aa00f037913c457c53864b4cad24e1d7ec 100644
--- a/src/account_schema.h
+++ b/src/account_schema.h
@@ -24,7 +24,7 @@
 
 /**
  * @file account_schema.h
- * @brief Account specfic keys/constants that must be shared in daemon and clients.
+ * @brief Account specific keys/constants that must be shared in daemon and clients.
  */
 
 namespace ring { namespace Conf {
diff --git a/src/dring/configurationmanager_interface.h b/src/dring/configurationmanager_interface.h
index 971e081eacee82cd2b854f564dd65ee98ea3b386..b79a8b1a1b36c34ee869324cc7b6c9df5c6c60f1 100644
--- a/src/dring/configurationmanager_interface.h
+++ b/src/dring/configurationmanager_interface.h
@@ -205,7 +205,7 @@ void enableProxyClient(const std::string& accountID, bool enable);
 void setPushNotificationToken(const std::string& pushDeviceToken);
 
 /**
- * To be called by clients with relevent data when a push notification is received.
+ * To be called by clients with relevant data when a push notification is received.
  */
 void pushNotificationReceived(const std::string& from, const std::map<std::string, std::string>& data);
 
@@ -313,7 +313,7 @@ struct ConfigurationSignal {
                 using cb_type = void(const std::string& /*accountId*/, const std::string& /*device*/, int /*status*/);
         };
         /**
-         * These are special getters for Android and UWP, so the daemon can retreive
+         * These are special getters for Android and UWP, so the daemon can retrieve
          * information only accessible through their respective platform APIs
          */
 #if defined(__ANDROID__) || (defined(TARGET_OS_IOS) && TARGET_OS_IOS)
diff --git a/src/dring/datatransfer_interface.h b/src/dring/datatransfer_interface.h
index ba0a84ed942e1828528d443709a03f56dc89349e..97ef49b6f1e0e9e8ff9561143d793a685bb05885 100644
--- a/src/dring/datatransfer_interface.h
+++ b/src/dring/datatransfer_interface.h
@@ -73,7 +73,7 @@ struct DataTransferInfo
     std::string peer; ///< Identifier of the remote peer (in the semantic of the associated account)
     std::string displayName; ///< Human oriented transfer name
     std::string path; ///< associated local file path if supported (empty, if not)
-    std::string mimetype; ///< MimeType of transfered data (https://www.iana.org/assignments/media-types/media-types.xhtml)
+    std::string mimetype; ///< MimeType of transferred data (https://www.iana.org/assignments/media-types/media-types.xhtml)
 };
 
 std::vector<DataTransferId> dataTransferList() noexcept;
@@ -93,7 +93,7 @@ std::vector<DataTransferId> dataTransferList() noexcept;
 ///
 /// Other fields are not used, but you must keep the default assigned value for compatibility.
 ///
-/// \param info a DataTransferInfo structure filled with information usefull for a file transfer.
+/// \param info a DataTransferInfo structure filled with information useful for a file transfer.
 /// \param[out] id data transfer identifiant if function succeed, usable with other APIs. Undefined value in case of error.
 ///
 /// \return DataTransferError::success if file is accepted for transfer, any other value in case of errors
@@ -114,7 +114,7 @@ DataTransferError sendFile(const DataTransferInfo& info, DataTransferId& id) noe
 /// \param id data transfer identification value as given by a DataTransferEvent signal.
 /// \param file_path file path going to be open in binary write mode to put incoming data.
 /// \param offset used to indicate the remote side about the number of bytes already received in
-/// a previous transfer session, usefull in transfer continuation mode.
+/// a previous transfer session, useful in transfer continuation mode.
 ///
 /// \return DataTransferError::invalid_argument if id is unknown.
 /// \note unknown \a id results to a no-op call.
diff --git a/src/dring/dring.h b/src/dring/dring.h
index 6d5b9b0895d39d32680d1686b51c76c51447b061..d6f12af94003aff97aa06bf0af3cf8fe74248a7e 100644
--- a/src/dring/dring.h
+++ b/src/dring/dring.h
@@ -52,7 +52,7 @@ bool init(enum InitFlag flags) noexcept;
 
 /**
  * Start asynchronously daemon created by init().
- * @returns true if daemon started successfuly
+ * @returns true if daemon started successfully
  */
 bool start(const std::string& config_file={}) noexcept;
 
@@ -81,7 +81,7 @@ void pollEvents() noexcept;
  * to keep compatibility over releases we don't let user directly provides
  * his callbacks as it or through a structure.
  * This way brings ABI violation if we need to change the order
- * and/or the existance of any callback type.
+ * and/or the existence of any callback type.
  * Thus the user have to pass them using following template classes
  * and functions, that wraps user-callback in a generic and ABI-compatible way.
  */
diff --git a/src/fileutils.h b/src/fileutils.h
index 7f143586262fa8eac2d6c1543db0fbf31c8fe318..bf3be6ca385b4e81d874eb1ec86867a53952564c 100644
--- a/src/fileutils.h
+++ b/src/fileutils.h
@@ -59,7 +59,7 @@ namespace ring { namespace fileutils {
     std::string get_cache_dir();
 
     /**
-     * Check directory existance and create it with given mode if it doesn't.
+     * Check directory existence and create it with given mode if it doesn't.
      * @param path to check, relative or absolute
      * @param dir last directory creation mode
      * @param parents default mode for all created directories except the last
diff --git a/src/generic_io.h b/src/generic_io.h
index e1e62e7f5ac02fcbb425de67617d8937b9f7a648..ae4703d1751080db72470407c07625f4d6e2e2f5 100644
--- a/src/generic_io.h
+++ b/src/generic_io.h
@@ -45,7 +45,7 @@ public:
     using RecvCb = std::function<ssize_t(const ValueType* buf, std::size_t len)>;
 
     /// Close established connection
-    /// \note Terminate oustanding blocking read operations with an empty error code, but a 0 read size.
+    /// \note Terminate outstanding blocking read operations with an empty error code, but a 0 read size.
     virtual void shutdown() {}
 
     /// Set Rx callback
diff --git a/src/ice_transport.h b/src/ice_transport.h
index c7959708341cfc35bab52f440c29639e4602389b..4c9462ee8226b169597144a0598c70e3459b3a14 100644
--- a/src/ice_transport.h
+++ b/src/ice_transport.h
@@ -88,7 +88,7 @@ public:
     bool isInitiator() const;
 
     /**
-     * Start tranport negociation between local candidates and given remote
+     * Start tranport negotiation between local candidates and given remote
      * to find the right candidate pair.
      * This function doesn't block, the callback on_negodone_cb will be called
      * with the negotiation result when operation is really done.
diff --git a/src/manager.cpp b/src/manager.cpp
index 09e54cc76bcc3279c6efe505066f33ca447c9b45..4721b59968dfd63bb7b1cafbd008906e2a893534 100644
--- a/src/manager.cpp
+++ b/src/manager.cpp
@@ -301,7 +301,7 @@ struct Manager::ManagerPimpl
 
     std::atomic_bool autoAnswer_ {false};
 
-    /** Application wide tone controler */
+    /** Application wide tone controller */
     ToneControl toneCtrl_;
 
     /** Current Call ID */
@@ -2020,7 +2020,7 @@ Manager::peerAnsweredCall(Call& call)
     const auto call_id = call.getCallId();
     RING_DBG("[call:%s] Peer answered", call_id.c_str());
 
-    // The if statement is usefull only if we sent two calls at the same time.
+    // The if statement is useful only if we sent two calls at the same time.
     if (isCurrentCall(call))
         stopTone();
 
diff --git a/src/manager.h b/src/manager.h
index 8f599c8bc0a788fd53ea13e4fedf0112c9d96119..6ff5b0af2d2ce56663ac48a50f16895e2403e48c 100644
--- a/src/manager.h
+++ b/src/manager.h
@@ -185,7 +185,7 @@ class Manager {
 
         /**
          * Attended transfer
-         * @param The call id to be transfered
+         * @param The call id to be transferred
          * @param The target
          */
         bool attendedTransfer(const std::string& transferID, const std::string& targetID);
@@ -233,7 +233,7 @@ class Manager {
         bool unHoldConference(const std::string& conference_id);
 
         /**
-         * Test if this id is a conference (usefull to test current call)
+         * Test if this id is a conference (useful to test current call)
          * @param the call id
          */
         bool isConference(const std::string& call_id) const;
@@ -690,7 +690,7 @@ class Manager {
 
         /**
          * @return true is there is one or many incoming call waiting
-         * new call, not anwsered or refused
+         * new call, not answered or refused
          */
         bool incomingCallsWaiting();
 
diff --git a/src/media/audio/audiobuffer.h b/src/media/audio/audiobuffer.h
index 01123dc266e7911188819d13a56c4f3dc34b4501..bbfbbe764622377d41e7f237ae3d74a52fd7b24c 100644
--- a/src/media/audio/audiobuffer.h
+++ b/src/media/audio/audiobuffer.h
@@ -245,7 +245,7 @@ class AudioBuffer {
          * Convert fixed-point channel to float and write in the out buffer (Float 32-bits).
          * The out buffer must be at least of size capacity()*sizeof(float) bytes.
          *
-         * @returns Number of samples writen.
+         * @returns Number of samples written.
          */
         size_t channelToFloat(float* out, const int& channel) const;
 
@@ -253,7 +253,7 @@ class AudioBuffer {
          * Write interleaved multichannel data to the out buffer (fixed-point 16-bits).
          * The out buffer must be at least of size capacity()*sizeof(AudioSample) bytes.
          *
-         * @returns Number of samples writen.
+         * @returns Number of samples written.
          */
         size_t interleave(AudioSample* out) const;
 
@@ -261,7 +261,7 @@ class AudioBuffer {
          * Write null data (silence) to the out buffer (fixed-point 16-bits).
          * The out buffer must be at least of size capacity()*sizeof(AudioSample) bytes.
          *
-         * @returns Number of samples writen.
+         * @returns Number of samples written.
          */
         size_t fillWithZero(AudioSample* out) const;
 
@@ -269,7 +269,7 @@ class AudioBuffer {
          * Write interleaved multichannel data to the out buffer (fixed-point 16-bits).
          * The out buffer is resized to hold the full content of this buffer.
          *
-         * @returns Number of samples writen.
+         * @returns Number of samples written.
          */
         size_t interleave(std::vector<AudioSample>& out) const;
 
@@ -282,7 +282,7 @@ class AudioBuffer {
          * Write interleaved multichannel data to the out buffer, while samples are converted to float.
          * The out buffer must be at least of size capacity()*sizeof(float) bytes.
          *
-         * @returns Number of samples writen.
+         * @returns Number of samples written.
          */
         size_t interleaveFloat(float* out) const;
 
diff --git a/src/media/audio/audiorecord.h b/src/media/audio/audiorecord.h
index 0c6b0b4a59fe333637150d1e8cb61393f5a73fc6..0d00fa8df470bd5ff29ddd3f7f4f5236af831722 100644
--- a/src/media/audio/audiorecord.h
+++ b/src/media/audio/audiorecord.h
@@ -54,7 +54,7 @@ class AudioRecord {
 
         /**
          * Check if no other file is opened, then create a new one
-         * @param filename A string containing teh file (with/without extension)
+         * @param filename A string containing the file (with/without extension)
          * @param type     The sound file format (FILE_RAW, FILE_WAVE)
          * @param format   Internal sound format (INT16 / INT32)
          * @return bool    True if file was opened
diff --git a/src/media/audio/opensl/audio_player.cpp b/src/media/audio/opensl/audio_player.cpp
index 5f7c88aa2cf912afc4f7e36d76d27b1255f63555..f0ee2a0765926f9f0fc590020f0703cdabf0f3b0 100644
--- a/src/media/audio/opensl/audio_player.cpp
+++ b/src/media/audio/opensl/audio_player.cpp
@@ -27,7 +27,7 @@ namespace opensl {
 
 /*
  * Called by OpenSL SimpleBufferQueue for every audio buffer played
- * directly pass thru to our handler.
+ * directly pass through to our handler.
  * The regularity of this callback from openSL/Android System affects
  * playback continuity. If it does not callback in the regular time
  * slot, you are under big pressure for audio processing[here we do
diff --git a/src/media/audio/ringbuffer.h b/src/media/audio/ringbuffer.h
index 39fde11d4f5f5379b740b828472f152d239bc392..de1b765825c3b964693705a2e5a64e4208c9c50b 100644
--- a/src/media/audio/ringbuffer.h
+++ b/src/media/audio/ringbuffer.h
@@ -145,7 +145,7 @@ class RingBuffer {
         NON_COPYABLE(RingBuffer);
 
         /**
-         * Return the smalest readoffset. Usefull to evaluate if ringbuffer is full
+         * Return the smalest readoffset. Useful to evaluate if ringbuffer is full
          */
         size_t getSmallestReadOffset() const;
 
diff --git a/src/media/audio/ringbufferpool.h b/src/media/audio/ringbufferpool.h
index 16780773bf9beb13435e047b66b4dfd2d6739c54..3a5713579254d39b82aed6be540aaa758e87858a 100644
--- a/src/media/audio/ringbufferpool.h
+++ b/src/media/audio/ringbufferpool.h
@@ -57,7 +57,7 @@ class RingBufferPool {
         void setInternalAudioFormat(AudioFormat format);
 
         /**
-         * Bind together two audio streams so taht a client will be able
+         * Bind together two audio streams so that a client will be able
          * to put and get data specifying its callid only.
          */
         void bindCallID(const std::string& call_id1,
@@ -104,7 +104,7 @@ class RingBufferPool {
         /**
          * Create a new ringbuffer with a default readoffset.
          * This class keeps a weak reference on returned pointer,
-         * so the caller is responsible of the refered instance.
+         * so the caller is responsible of the referred instance.
          */
         std::shared_ptr<RingBuffer> createRingBuffer(const std::string& id);
 
diff --git a/src/media/audio/tonecontrol.h b/src/media/audio/tonecontrol.h
index 4d856735f6718b481887f40b2affbd8f7e7a369b..b8b47f110dea23873c9cf2547993d83b20da14a7 100644
--- a/src/media/audio/tonecontrol.h
+++ b/src/media/audio/tonecontrol.h
@@ -32,7 +32,7 @@ namespace ring {
  * ToneControl is a class to handle application wide business logic
  * to control audio tones played at various application events.
  * Having an application wide instance gives a way to handle
- * complexes interactions occuring in a multi-call context.
+ * complexes interactions occurring in a multi-call context.
  */
 
 class TelephoneTone;
diff --git a/src/media/media_codec.h b/src/media/media_codec.h
index d59dbb17fc24fa8829cbaf046eabcc121061821d..9fea97137ef4e1d33d5b66a9b17e45d12578f819 100644
--- a/src/media/media_codec.h
+++ b/src/media/media_codec.h
@@ -159,7 +159,7 @@ struct AccountCodecInfo
     AccountCodecInfo& operator=(AccountCodecInfo&&);
 
     const SystemCodecInfo& systemCodecInfo;
-    unsigned order {0}; /*used to define prefered codec list order in UI*/
+    unsigned order {0}; /*used to define preferred codec list order in UI*/
     bool isActive {true};
     /* account custom values */
     unsigned payloadType;
diff --git a/src/preferences.cpp b/src/preferences.cpp
index 3d1b28a898bb3ff9fdbc2bbd2a72562d671cbae6..161d5c156f4dfdb9a78a3da6dac596bca9b9fb0f 100644
--- a/src/preferences.cpp
+++ b/src/preferences.cpp
@@ -139,7 +139,7 @@ constexpr const char * const VideoPreferences::CONFIG_LABEL;
 static const char * const DECODING_ACCELERATED_KEY = "decodingAccelerated";
 #endif
 
-static const char * const DFT_PULSE_LENGTH_STR = "250"; /** Default DTMF lenght */
+static const char * const DFT_PULSE_LENGTH_STR = "250"; /** Default DTMF length */
 static const char * const ALSA_DFT_CARD    = "0";          /** Default sound card index */
 
 Preferences::Preferences() :
diff --git a/src/ringdht/ringaccount.cpp b/src/ringdht/ringaccount.cpp
index d45c3ac997a59ba56c8be05903f654a022bc5a51..43fee13724a3200c2d1a96701648e5235e2c4ec1 100644
--- a/src/ringdht/ringaccount.cpp
+++ b/src/ringdht/ringaccount.cpp
@@ -3468,7 +3468,7 @@ void RingAccount::setPushNotificationToken(const std::string& token)
 }
 
 /**
- * To be called by clients with relevent data when a push notification is received.
+ * To be called by clients with relevant data when a push notification is received.
  */
 void RingAccount::pushNotificationReceived(const std::string& from, const std::map<std::string, std::string>& data)
 {
diff --git a/src/ringdht/ringaccount.h b/src/ringdht/ringaccount.h
index a80ecedcf86a5d871ce1bdf1d4cac81b72e2fc3f..927248ff3112a3bbb8e29e622dfa1b7f6ea9c4b1 100644
--- a/src/ringdht/ringaccount.h
+++ b/src/ringdht/ringaccount.h
@@ -372,7 +372,7 @@ class RingAccount : public SIPAccountBase {
         void setPushNotificationToken(const std::string& pushDeviceToken = "");
 
         /**
-         * To be called by clients with relevent data when a push notification is received.
+         * To be called by clients with relevant data when a push notification is received.
          */
         void pushNotificationReceived(const std::string& from, const std::map<std::string, std::string>& data);
 
diff --git a/src/security/tls_session.cpp b/src/security/tls_session.cpp
index d3fc48aafab4e3c7d20789fcfc1882b9853826ff..c38b47b7aba6ce66a2fa0432de4181c011192664 100644
--- a/src/security/tls_session.cpp
+++ b/src/security/tls_session.cpp
@@ -860,7 +860,7 @@ TlsSession::TlsSessionImpl::handleStateHandshake(TlsSessionState state)
     RING_DBG("[TLS] session established: %s", desc);
     gnutls_free(desc);
 
-    // Anonymous connection? rehandshake immediatly with certificate authentification forced
+    // Anonymous connection? rehandshake immediately with certificate authentification forced
     auto cred = gnutls_auth_get_type(session_);
     if (cred == GNUTLS_CRD_ANON) {
         RING_DBG("[TLS] renogotiate with certificate authentification");
@@ -1037,7 +1037,7 @@ TlsSession::TlsSessionImpl::handleDataPacket(std::vector<ValueType>&& buf, uint6
 ///
 /// Reorder and push received packet to upper layer
 ///
-/// \note This method must be called continously, faster than RX_OOO_TIMEOUT
+/// \note This method must be called continuously, faster than RX_OOO_TIMEOUT
 ///
 void
 TlsSession::TlsSessionImpl::flushRxQueue()
@@ -1064,7 +1064,7 @@ TlsSession::TlsSessionImpl::flushRxQueue()
     auto item = std::begin(reorderBuffer_);
     auto next_offset = item->first;
 
-    // Wait for next continous packet until timeout
+    // Wait for next continuous packet until timeout
     if ((clock::now() - lastReadTime_) >= RX_OOO_TIMEOUT) {
         // OOO packet timeout - consider waited packets as lost
         if (auto lost = next_offset - gapOffset_)
diff --git a/src/sip/pattern.cpp b/src/sip/pattern.cpp
index 09cc8cf0b96f0ca8dd7672fc71fe26b4685f8486..db0253c1fdddd2734aee1068dcac74dcc0a7285c 100644
--- a/src/sip/pattern.cpp
+++ b/src/sip/pattern.cpp
@@ -123,7 +123,7 @@ bool Pattern::matches()
         offset_[1] =  ovector_[1] + offset_[0];
     }
 
-    // Matching succeded but not enough space.
+    // Matching succeeded but not enough space.
     // @TODO figure out something more clever to do in this case.
     if (rc == 0)
         throw MatchError("No space to store all substrings.");
diff --git a/src/sip/pres_sub_client.h b/src/sip/pres_sub_client.h
index 0f81d0f18cdd972db77b32afc7a4c2b98b52202e..1daf1b130689d5a83d9a6157a20ee1ff722de6d1 100644
--- a/src/sip/pres_sub_client.h
+++ b/src/sip/pres_sub_client.h
@@ -78,7 +78,7 @@ class PresSubClient {
         bool subscribe();
         /**
          * Send a SUBCRIBE to the PXB or directly to a pres_client in the IP2IP context but
-         * the 0s timeout make the dialog expire immediatly.
+         * the 0s timeout make the dialog expire immediately.
          */
         bool unsubscribe();
         /**
diff --git a/src/sip/pres_sub_server.cpp b/src/sip/pres_sub_server.cpp
index cf25fdabbf61766b61e2b0e28cbde4613be3d0ee..7ffa9937057cd2ba6d65e176b6dfd29271b9a1a1 100644
--- a/src/sip/pres_sub_server.cpp
+++ b/src/sip/pres_sub_server.cpp
@@ -227,7 +227,7 @@ PresSubServer::pres_on_rx_subscribe_request(pjsip_rx_data *rdata)
         return PJ_TRUE;
     }
 
-    /*Send notify immediatly. Replace real status with fake.*/
+    /*Send notify immediately. Replace real status with fake.*/
 
     // pjsip_pres_set_status(sub, pres->getStatus()); // real status
 
diff --git a/src/sip/pres_sub_server.h b/src/sip/pres_sub_server.h
index b6b0a291973d38987356125b83e5255e92291c23..32878649e752686be653c6871517bfad4643539e 100644
--- a/src/sip/pres_sub_server.h
+++ b/src/sip/pres_sub_server.h
@@ -43,8 +43,8 @@ class PresSubServer {
         PresSubServer(SIPPresence * pres, pjsip_evsub *evsub, const char *remote, pjsip_dialog *d);
         ~PresSubServer();
         /*
-         * Acces to the evsub expire variable.
-         * It was recieved in the SUBSCRIBE request.
+         * Access to the evsub expire variable.
+         * It was received in the SUBSCRIBE request.
          */
         void setExpires(int ms);
         int getExpires() const;
diff --git a/src/sip/sdes_negotiator.cpp b/src/sip/sdes_negotiator.cpp
index 4439e9c2d026329693a08f66ff57d0ccdf163764..35dbaf5c5b39814fc5f295a9f880789769b908cf 100644
--- a/src/sip/sdes_negotiator.cpp
+++ b/src/sip/sdes_negotiator.cpp
@@ -109,7 +109,7 @@ SdesNegotiator::parse(const std::vector<std::string>& attributes)
         } else
             return cryptoAttributeVector;
 
-        // Check if the crypto suite is valid and retreive
+        // Check if the crypto suite is valid and retrieve
         // its value.
         cryptoSuitePattern->updateSubject(sdesLine.at(1));
 
diff --git a/src/sip/sipaccount.h b/src/sip/sipaccount.h
index 7f5d2d57ff50e01be6b7e42ffe73b3c39e2eee31..578dba95cf9bcf5f2f256d82899441b50dd36772 100644
--- a/src/sip/sipaccount.h
+++ b/src/sip/sipaccount.h
@@ -241,7 +241,7 @@ class SIPAccount : public SIPAccountBase {
         }
 
         /**
-         * Get the registration stucture that is used
+         * Get the registration structure that is used
          * for PJSIP in the registration process.
          * Settings are loaded from configuration file.
          * @return pjsip_regc* A pointer to the registration structure
diff --git a/src/sip/sipaccountbase.h b/src/sip/sipaccountbase.h
index d943bc80ada2b8a57de0f2e3d1835a86e674db72..d9c4319bd702618e7ac0afde2a440f9b39cf99c5 100644
--- a/src/sip/sipaccountbase.h
+++ b/src/sip/sipaccountbase.h
@@ -149,7 +149,7 @@ public:
 
     /**
      * Determine if TLS is enabled for this account. TLS provides a secured channel for
-     * SIP signalization. It is independant of the media encription (as provided by SRTP).
+     * SIP signalization. It is independent of the media encryption (as provided by SRTP).
      */
     virtual bool isTlsEnabled() const {
         return false;
diff --git a/src/sip/siptransport.cpp b/src/sip/siptransport.cpp
index 19365d0d4ae9ef5baefd1b92fcc1bd5d9bdd63ae..94b1d111946fd60bf2d3d72a30b29b61dc028b99 100644
--- a/src/sip/siptransport.cpp
+++ b/src/sip/siptransport.cpp
@@ -450,7 +450,7 @@ SipTransportBroker::getTlsIceTransport(const std::shared_ptr<ring::IceTransport>
 
     {
         std::lock_guard<std::mutex> lock(transportMapMutex_);
-        // we do not check for key existance as we've just created it
+        // we do not check for key existence as we've just created it
         // (member of new SipIceTransport instance)
         transports_.emplace(std::make_pair(tr, sip_tr));
     }
diff --git a/src/sip/siptransport.h b/src/sip/siptransport.h
index ff9b6554e745aff20991e43480c94c8d15019702..a7f7f36175b79d1d12f7a3c5d13b73433a3668a5 100644
--- a/src/sip/siptransport.h
+++ b/src/sip/siptransport.h
@@ -190,7 +190,7 @@ public:
     std::shared_ptr<SipTransport> addTransport(pjsip_transport*);
 
     /**
-     * Start gracefull shutdown procedure for all transports
+     * Start graceful shutdown procedure for all transports
      */
     void shutdown();
 
@@ -214,7 +214,7 @@ private:
     std::mutex transportMapMutex_ {};
 
     /**
-     * Transports are stored in this map in order to retreive them in case
+     * Transports are stored in this map in order to retrieve them in case
      * several accounts would share the same port number.
      */
     std::map<SipTransportDescr, pjsip_transport*> udpTransports_;
diff --git a/src/sip/sipvoiplink.cpp b/src/sip/sipvoiplink.cpp
index aed5c132dbf17f73dd75d6bef51430d65c93461c..598e1b241e6d1a957aedd9e26959b4684bd5fd6c 100644
--- a/src/sip/sipvoiplink.cpp
+++ b/src/sip/sipvoiplink.cpp
@@ -232,7 +232,7 @@ transaction_request_cb(pjsip_rx_data *rdata)
                     Manager::instance().startVoiceMessageNotification(account_id, voicemail);
             }
         } else if (request.find("MESSAGE") != std::string::npos) {
-            // Reply 200 immediatly (RFC 3428, ch. 7)
+            // Reply 200 immediately (RFC 3428, ch. 7)
             try_respond_stateless(endpt_, rdata, PJSIP_SC_OK, nullptr, nullptr, nullptr);
             // Process message content in case of multi-part body
             auto payloads = im::parseSipMessage(rdata->msg_info.msg);
@@ -396,7 +396,7 @@ transaction_request_cb(pjsip_rx_data *rdata)
         return PJ_FALSE;
     }
 
-    // Check if call has been transfered
+    // Check if call has been transferred
     pjsip_tx_data *tdata = 0;
 
     if (pjsip_inv_initial_answer(call->inv.get(), rdata, PJSIP_SC_TRYING, NULL, NULL, &tdata) != PJ_SUCCESS) {
@@ -452,7 +452,7 @@ tp_state_callback(pjsip_transport* tp, pjsip_transport_state state,
 {
     // There is no way (at writing) to link a user data to a PJSIP transport.
     // So we obtain it from the global SIPVoIPLink instance that owns it.
-    // Be sure the broker's owner is not deleted during proccess
+    // Be sure the broker's owner is not deleted during process
     if (auto sipLink = getSIPVoIPLink()) {
         if (auto& broker = sipLink->sipTransportBroker)
             broker->transportStateChanged(tp, state, info);
diff --git a/src/upnp/upnp_context.cpp b/src/upnp/upnp_context.cpp
index 30b4cb03bb802ff88076fbce05b1a188382bc417..7a50b3774d7d5a159a40be0f50b34e0dc1dfc7af 100644
--- a/src/upnp/upnp_context.cpp
+++ b/src/upnp/upnp_context.cpp
@@ -1040,7 +1040,7 @@ UPnPContext::handleUPnPEvents(Upnp_EventType event_type, const void* event)
     case UPNP_EVENT_SUBSCRIBE_COMPLETE:
         /* RING_DBG("UPnP: Control Point async subscription complete"); */
 
-        /* TODO: check if successfull */
+        /* TODO: check if successful */
 
         break;
 
@@ -1215,7 +1215,7 @@ UPnPContext::removeMappingsByLocalIPAndDescription(const UPnPIGD& igd, const std
                     /* failed to delete entry, skip it and try the next one */
                     ++entry_idx;
                 }
-                /* note: in the case that the entry deletion is successfull, we do not increment the entry
+                /* note: in the case that the entry deletion is successful, we do not increment the entry
                  *       idx as the number of entries has decreased by one */
             } else
                 ++entry_idx;
diff --git a/src/upnp/upnp_context.h b/src/upnp/upnp_context.h
index 1ce949caa870184c3bc259dc74b7899cd39542b7..6553db7fd3515382310e542825d549e3752be343 100644
--- a/src/upnp/upnp_context.h
+++ b/src/upnp/upnp_context.h
@@ -148,7 +148,7 @@ private:
     IGD* chooseIGD_unlocked() const;
     bool hasValidIGD_unlocked() const;
 
-    /* tries to add mapping, assumes you alreayd have lock on igd_mutex_ */
+    /* tries to add mapping, assumes you already have lock on igd_mutex_ */
     Mapping addMapping(IGD* igd,
                        uint16_t port_external,
                        uint16_t port_internal,
diff --git a/src/windirent.h b/src/windirent.h
index 89f4df49f82b275f78e028bf9b6670d5b78f687d..92d16b6e6583a497e102f318a19f5097370f8cdf 100644
--- a/src/windirent.h
+++ b/src/windirent.h
@@ -590,7 +590,7 @@ dirent_next(
             /* Got a file */
             p = &dirp->data;
         } else {
-            /* The very last entry has been processed or an error occured */
+            /* The very last entry has been processed or an error occurred */
             FindClose (dirp->handle);
             dirp->handle = INVALID_HANDLE_VALUE;
             p = NULL;
diff --git a/test/sip/test_SIP.cpp b/test/sip/test_SIP.cpp
index 1d027d0f1164d09c2641ae21298ba88c711117a3..0281dd4207f367501c1405983fc0389e5e037ae2 100644
--- a/test/sip/test_SIP.cpp
+++ b/test/sip/test_SIP.cpp
@@ -173,7 +173,7 @@ test_SIP::testSimpleOutgoingIpCall()
 void
 test_SIP::testSimpleIncomingIpCall()
 {
-    std::cout << ">>>> test simple incomming IP call <<<< " << '\n';
+    std::cout << ">>>> test simple incoming IP call <<<< " << '\n';
 
     CPPUNIT_ASSERT(Manager::instance().callFactory.empty());
 
diff --git a/test/unitTest/account_factory/testAccount_factory.cpp b/test/unitTest/account_factory/testAccount_factory.cpp
index d7845f4143bce9981dbd444474681362e40ddfd4..8a47f179db36b647a7e22baf7b7fe646aa33ef79 100644
--- a/test/unitTest/account_factory/testAccount_factory.cpp
+++ b/test/unitTest/account_factory/testAccount_factory.cpp
@@ -75,7 +75,7 @@ Account_factoryTest::tearDown()
 void
 Account_factoryTest::testAddRemoveSIPAccount()
 {
-    // verify if there is no account at the begining
+    // verify if there is no account at the beginning
     CPPUNIT_ASSERT(accountFactory->empty());
     CPPUNIT_ASSERT(accountFactory->accountCount()==0);
 
@@ -95,7 +95,7 @@ Account_factoryTest::testAddRemoveSIPAccount()
 void
 Account_factoryTest::testAddRemoveRINGAccount()
 {
-    // verify if there is no account at the begining
+    // verify if there is no account at the beginning
     CPPUNIT_ASSERT(accountFactory->empty());
     CPPUNIT_ASSERT(accountFactory->accountCount()==0);
 
@@ -115,7 +115,7 @@ Account_factoryTest::testAddRemoveRINGAccount()
 void
 Account_factoryTest::testClear()
 {
-    // verify if there is no account at the begining
+    // verify if there is no account at the beginning
     CPPUNIT_ASSERT(accountFactory->empty());
     CPPUNIT_ASSERT(accountFactory->accountCount()==0);
 
diff --git a/test/unitTest/fileutils/testFileutils.cpp b/test/unitTest/fileutils/testFileutils.cpp
index e4594aed0878d9950c7eb428309f868db2a3433f..f15ca797f3906f10b3bad8de3e54f2ca93315dfb 100644
--- a/test/unitTest/fileutils/testFileutils.cpp
+++ b/test/unitTest/fileutils/testFileutils.cpp
@@ -107,7 +107,7 @@ FileutilsTest::testCheckDir()
     CPPUNIT_ASSERT(isDirectory(NON_EXISTANT_PATH));
     CPPUNIT_ASSERT(removeAll(NON_EXISTANT_PATH_BASE) == 0);
     CPPUNIT_ASSERT(!isDirectory(NON_EXISTANT_PATH_BASE));
-    //remove an non existant directory
+    //remove an non existent directory
     CPPUNIT_ASSERT(removeAll(NON_EXISTANT_PATH_BASE) == -1);
 }
 
diff --git a/tools/asterisk/extensions.conf b/tools/asterisk/extensions.conf
index 7c92a2d2f166c3fe6f3fe1fbd57418c6c18968b8..d750f6dc0313d3b73c0909f6092da33838cce2b6 100644
--- a/tools/asterisk/extensions.conf
+++ b/tools/asterisk/extensions.conf
@@ -303,7 +303,7 @@ exten => _91700XXXXXXX,1,Dial(IAX2/${GLOBAL(IAXINFO)}@iaxtel.com/${EXTEN:1}@iaxt
 ; The SWITCH statement permits a server to share the dialplan with
 ; another server. Use with care: Reciprocal switch statements are not
 ; allowed (e.g. both A -> B and B -> A), and the switched server needs
-; to be on-line or else dialing can be severly delayed.
+; to be on-line or else dialing can be severely delayed.
 ;
 [iaxprovider]
 ;switch => IAX2/user:[key]@myserver/mycontext
diff --git a/tools/asterisk/sip.conf b/tools/asterisk/sip.conf
index 5ec53dfb8774ddf14ef30c7515b44efdd7a8cf24..b1dbe4e9c6a69aa9db670ea21c46fb27546a0e2f 100644
--- a/tools/asterisk/sip.conf
+++ b/tools/asterisk/sip.conf
@@ -83,7 +83,7 @@
 ;	1. Asterisk checks the SIP From: address username and matches against
 ;	   names of devices with type=user
 ;	   The name is the text between square brackets [name]
-;	2. Asterisk checks the From: addres and matches the list of devices
+;	2. Asterisk checks the From: address and matches the list of devices
 ;	   with a type=peer
 ;	3. Asterisk checks the IP address (and port number) that the INVITE
 ;	   was sent from and matches against any devices with type=peer
@@ -219,7 +219,7 @@ tlsbindaddr=0.0.0.0:5061        ; IP address for TLS server to bind to (0.0.0.0)
                                 ; ability to place SIP calls based on domain
                                 ; names to some other SIP users on the Internet
                                 ; Specifying a port in a SIP peer definition or
-                                ; when dialing outbound calls will supress SRV
+                                ; when dialing outbound calls will suppress SRV
                                 ; lookups for that peer or call.
 
 ;pedantic=yes                   ; Enable checking of tags in headers,
@@ -786,7 +786,7 @@ tlscertfile=/etc/asterisk/keys/asterisk.pem ; Certificate file (*.pem format onl
 ; 'comedia RTP handling' refers to the technique of sending RTP to the port that the
 ; the other endpoint's RTP arrived from, and means 'connection-oriented media'. This is
 ; only partially related to RFC 4145 which was referred to as COMEDIA while it was in
-; draft form. This method is used to accomodate endpoints that may be located behind
+; draft form. This method is used to accommodate endpoints that may be located behind
 ; NAT devices, and as such the port number they tell Asterisk to send RTP packets to
 ; for their media streams is not actual port number that will be used on the nearer
 ; side of the NAT.
diff --git a/tools/cpplint.py3 b/tools/cpplint.py3
index a71d673a7101d7f12899ea53b7d427262c40f633..75f31d04a3b8928913a578dd7a070c7733289dcb 100755
--- a/tools/cpplint.py3
+++ b/tools/cpplint.py3
@@ -6299,7 +6299,7 @@ def ParseArguments(args):
       try:
           _valid_extensions = set(val.split(','))
       except ValueError:
-          PrintUsage('Extensions must be comma seperated list.')
+          PrintUsage('Extensions must be comma separated list.')
 
   if not filenames:
     PrintUsage('No files were specified.')
diff --git a/tools/dringctrl/controler.py b/tools/dringctrl/controler.py
index 3539d89f7298570211674f8dcffb2fec2472a569..f0d0a97ca316749c5ec141218ab0282bb5fac833 100644
--- a/tools/dringctrl/controler.py
+++ b/tools/dringctrl/controler.py
@@ -18,7 +18,7 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA.
 #
 
-"""DRing controling class through DBUS"""
+"""DRing controlling class through DBUS"""
 
 import sys
 import os
diff --git a/tools/dringctrl/dringctrl.py b/tools/dringctrl/dringctrl.py
index b1eecc24defe23f8187c800759b56844739ed803..1a3ddd97dd6fa1e42718766564d02a489bacfce3 100755
--- a/tools/dringctrl/dringctrl.py
+++ b/tools/dringctrl/dringctrl.py
@@ -33,7 +33,7 @@ except Exception as e:
     exit(1)
 
 from errors import *
-from controler import DRingCtrl
+from controller import DRingCtrl
 from tester import DRingTester
 
 if __name__ == "__main__":
diff --git a/tools/dringctrl/dringctrl_testdbus.py b/tools/dringctrl/dringctrl_testdbus.py
index 9232edf646006cc616127ac2228f834869cc3a3d..87dd771faccf5ed451eff647c8ac3196eb77d476 100644
--- a/tools/dringctrl/dringctrl_testdbus.py
+++ b/tools/dringctrl/dringctrl_testdbus.py
@@ -25,7 +25,7 @@ PHONE3="14142"
 
 
 # Define function callback to emulate UA behavior on
-# recieving a call (peer hangup))
+# receiving a call (peer hangup))
 def acceptOnIncomingCall(sflphone):
 
     sflphone.Accept(sflphone.currentCallId)
diff --git a/tools/dringctrl/sendfile.py b/tools/dringctrl/sendfile.py
index 3c83db5554f750c040c8b7fc7ba2a52250ab2ad9..5ed4282f83ad053db85f76132472eb2e0f1af1ae 100644
--- a/tools/dringctrl/sendfile.py
+++ b/tools/dringctrl/sendfile.py
@@ -17,14 +17,14 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA.
 
-from controler import DRingCtrl
+from controller import DRingCtrl
 
 import argparse
 import sys
 import signal
 import os.path
 
-class Controler(DRingCtrl):
+class Controller(DRingCtrl):
     def onDataTransferEvent(self, transferId, code):
         if code == 6:
             print("transfer %u has been cancelled by host" % transferId)
@@ -39,7 +39,7 @@ parser.add_argument('--filename', help='Pathname on file to send', metavar='<fil
 parser.add_argument('--displayname', help='Name displayed to peer', metavar='<displayname>', type=str)
 
 args = parser.parse_args()
-ctrl = Controler(sys.argv[0], False)
+ctrl = Controller(sys.argv[0], False)
 
 if not args.account:
     for account in ctrl.getAllEnabledAccounts():
diff --git a/tools/dringctrl/sippwrap.py b/tools/dringctrl/sippwrap.py
index 0bdc07355893fca4a475267d00707323b3e84f97..3ef946945e083fbb7b254763d767736211eedf64 100644
--- a/tools/dringctrl/sippwrap.py
+++ b/tools/dringctrl/sippwrap.py
@@ -21,7 +21,7 @@
 import os
 
 class SippWrapper:
-    """ Wrapper taht allow for managing sipp command line easily """
+    """ Wrapper that allow for managing sipp command line easily """
 
     def __init__(self):
         self.commandLine = "./sipp"
diff --git a/tools/dringctrl/test_dring_dbus_interface.py b/tools/dringctrl/test_dring_dbus_interface.py
index 34dfee8a274b084c99b72b520f0b27f6eb31902e..7eb8a0957c044b1ffc80a22cb275ca4831d86b71 100644
--- a/tools/dringctrl/test_dring_dbus_interface.py
+++ b/tools/dringctrl/test_dring_dbus_interface.py
@@ -64,7 +64,7 @@ class SippCtrl:
         sippInstance.launch()
 
     def find_sipp_pid(self):
-        # Retreive the PID of the last
+        # Retrieve the PID of the last
         # The /proc/PID/cmdline contain the command line from
         pids = [int(x) for x in os.listdir("/proc") if x.isdigit()]
         sippPid = [pid for pid in pids if "sipp" in open("/proc/" + str(pid) + "/cmdline").readline()]
diff --git a/tools/dringctrl/tester.py b/tools/dringctrl/tester.py
index c9bc00965439dc8aed892da08ba9dfbb49dbc5f5..c516aedda7626659ff68ac43d6179c97785518b6 100644
--- a/tools/dringctrl/tester.py
+++ b/tools/dringctrl/tester.py
@@ -252,7 +252,7 @@ class DRingTester():
             if (currBitrate > self.maxBitrate):
                 currBitrate = self.minBitrate
 
-        print("**[SUCESS] VIDEO Bitrate Test")
+        print("**[SUCCESS] VIDEO Bitrate Test")
         print("**[END] VIDEO Bitrate Test")
 
 # testSimultaneousLoopCallDht
@@ -281,7 +281,7 @@ class DRingTester():
 
             count += 1
 
-        print("**[SUCESS] Simultaneous DHT call test")
+        print("**[SUCCESS] Simultaneous DHT call test")
         print("**[END] Simultaneous DHT call test")
diff --git a/src/sip/sipcall.cpp b/src/sip/sipcall.cpp
index c81c4ddcdd7ede228821712e887b4b56fdb69ce7..6246d63e16b56a5b0024982c94a2b4eae2f1dd46 100644
--- a/src/sip/sipcall.cpp
+++ b/src/sip/sipcall.cpp
@@ -1014,7 +1014,7 @@ SIPCall::waitForIceAndStartMedia()
             if (!ice->isInitialized())
                 return true;
 
             // Start transport on SDP data and wait for negotation
             auto rem_ice_attrs = call->sdp_->getIceAttributes();
             if (rem_ice_attrs.ufrag.empty() or rem_ice_attrs.pwd.empty()) {
                 RING_ERR("[call:%s] Media ICE attributes empty", call->getCallId().c_str());
@@ -1033,7 +1033,7 @@ SIPCall::waitForIceAndStartMedia()
                     auto ice = call->getIceMediaTransport();
 
                     if (ice->isFailed()) {
-                        RING_ERR("[call:%s] Media ICE negotation failed", call->getCallId().c_str());
+                        RING_ERR("[call:%s] Media ICE negotiation failed", call->getCallId().c_str());
                         call->onFailure(EIO);
                         return false;
                     }
@@ -1081,7 +1081,7 @@ SIPCall::openPortsUPnP()
          * Try to open the desired ports with UPnP,
          * if they are used, use the alternative port and update the SDP session with the newly chosen port(s)
          *
-         * TODO: the inital ports were chosen from the list of available ports and were marked as used
+         * TODO: the initial ports were chosen from the list of available ports and were marked as used
          *       the newly selected port should possibly be checked against the list of used ports and marked
          *       as used, the old port should be "released"
          */
@@ -1014,7 +1014,7 @@ SIPCall::waitForIceAndStartMedia()
                 return true;
 
-            // Start transport on SDP data and wait for negotation
+            // Start transport on SDP data and wait for negotiation
             auto rem_ice_attrs = call->sdp_->getIceAttributes();
             if (rem_ice_attrs.ufrag.empty() or rem_ice_attrs.pwd.empty()) {